# Docsets

Audience-specific documentation tracks for trace.

## Developer

- [Internal Developer Docset](./developer/internal/)
- [External Developer Docset](./developer/external/)

## User

- [Technical User Docset](./user/)

## Agent

- [Agent Operator Docset](./agent/)
